use strictures 2;

use Test::More tests => 13;
use Test::Command::Simple;

my $CMD = $ENV{'LICENSECHECK'} || 'bin/licensecheck';

subtest 'encoding; UTF-8' => sub {
	run_ok $CMD, qw(-m --copyright --encoding utf8 t/encoding/copr-utf8.h);
	like stdout,
		qr{GPL \(v2 or later\)	2004-2015 Oliva 'f00' Oberto / 2001-2010 Paul 'bar' Stevénsön},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; UTF-8 misparsed raw' => sub {
	run_ok $CMD, qw(-m --copyright t/encoding/copr-utf8.h);
	like stdout,
		qr{GPL \(v2 or later\)	2004-2015 Oliva 'f00' Oberto / 2001-2010 Paul 'bar' StevÃ©nsÃ¶n},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; UTF-8 misparsed by guessing' => sub {
	run_ok $CMD, qw(-m --copyright --encoding Guess t/encoding/copr-utf8.h);
	like stdout,
		qr{GPL \(v2 or later\)	2004-2015 Oliva 'f00' Oberto / 2001-2010 Paul 'bar' StevÃ©nsÃ¶n},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; UTF-8 misparsed as ISO 8859-1' => sub {
	run_ok $CMD,
		qw(-m --copyright --encoding iso-8859-1 t/encoding/copr-utf8.h);
	like stdout,
		qr{GPL \(v2 or later\)	2004-2015 Oliva 'f00' Oberto / 2001-2010 Paul 'bar' StevÃ©nsÃ¶n},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; ISO 8859-1' => sub {
	run_ok $CMD,
		qw(-m --copyright --encoding iso-8859-1 t/encoding/copr-iso8859.h);
	like stdout,
		qr{GPL \(v2\) \(with incorrect FSF address\)	2011 Heinrich Müller <henmull\@src.gnome.org>},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; ISO 8859-1 parsed raw' => sub {
	run_ok $CMD, qw(-m --copyright t/encoding/copr-iso8859.h);
	like stdout,
		qr{GPL \(v2\) \(with incorrect FSF address\)	2011 Heinrich Müller <henmull\@src.gnome.org>},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; ISO 8859-1 parsed by guessing' => sub {
	run_ok $CMD,
		qw(-m --copyright --encoding Guess t/encoding/copr-iso8859.h);
	like stdout,
		qr{GPL \(v2\) \(with incorrect FSF address\)	2011 Heinrich Müller <henmull\@src.gnome.org>},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; fails misparsing ISO 8859-1 as UTF-8' => sub {
	run_ok $CMD,
		qw(-m --copyright --encoding utf8 t/encoding/copr-iso8859.h),
		'Testing stdout';
	like stdout,
		qr{GPL \(v2\) \(with incorrect FSF address\)	2011 Heinrich Müller <henmull\@src.gnome.org>},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; EUC' => sub {
	run_ok $CMD,
		qw(-m --copyright --encoding euc-jp t/encoding/README.gs550j);
	like stdout,
		qr{UNKNOWN	1999 大森紀人 \(ohmori\@p.chiba-u.ac.jp\) / 1999 Norihito Ohmori. / 1996-1999 Daisuke SUZUKI.},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; EUC misparsed raw' => sub {
	run_ok $CMD, qw(-m --copyright t/encoding/README.gs550j);
	like stdout,
		qr{UNKNOWN	1999 Âç¿¹µª¿Í \(ohmori\@p.chiba-u.ac.jp\) / 1999 Norihito Ohmori. / 1996-1999 Daisuke SUZUKI.},
		'Testing stdout';
	like stderr, qr{|utf8 .* does not map to Unicode at};
};
subtest 'encoding; EUC misparsed by Guess' => sub {
	run_ok $CMD, qw(-m --copyright --encoding Guess t/encoding/README.gs550j);
	like stdout,
		qr{UNKNOWN	1999 Âç¿¹µª¿Í \(ohmori\@p.chiba-u.ac.jp\) / 1999 Norihito Ohmori. / 1996-1999 Daisuke SUZUKI.},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; EUC parsed as ISO 8859-1' => sub {
	run_ok $CMD,
		qw(-m --copyright --encoding iso-8859-1 t/encoding/README.gs550j);
	like stdout,
		qr{UNKNOWN	1999 Âç¿¹µª¿Í \(ohmori\@p.chiba-u.ac.jp\) / 1999 Norihito Ohmori. / 1996-1999 Daisuke SUZUKI.},
		'Testing stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
subtest 'encoding; fails misparsing EUC as UTF-8' => sub {
	run_ok $CMD,
		qw(-m --copyright --encoding utf8 t/encoding/README.gs550j),
		'Testing stdout';
	cmp_ok stdout, 'eq', '', 'No stdout';
	cmp_ok stderr, 'eq', '', 'No stderr';
};
